==> haskell-contravariant-extras-0.3.4-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.4
id: contravariant-extras-0.3.4-6KPikGErH6JFY1GxYeFsWF
key: contravariant-extras-0.3.4-6KPikGErH6JFY1GxYeFsWF
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
abi: b0320e129fae25e9c4c825b327d6cb2f
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
import-dirs: /usr/lib/ghc-8.4.3/site-local/contravariant-extras-0.3.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/contravariant-extras-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/contravariant-extras-0.3.4
hs-libraries: HScontravariant-extras-0.3.4-6KPikGErH6JFY1GxYeFsWF
depends:
    base-4.11.1.0 tuple-th-0.2.5-JqgdKcUf4b37FvYBt3sxeA
    template-haskell-2.13.0.0 contravariant-1.5-5VBqEYOPGpyDW8QIali4BA
    base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tuple-th-0.2.5-JqgdKcUf4b37FvYBt3sxeA=61e77e3aac5fd226d5ea0f5b7e73ae9c
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             base-prelude-1.3-6USA4MwBClb3KaEhnb0gD7=6440a7e70ad5450b51ffd7c9c4277ed3
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-extras-0.3.4-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.4
id: contravariant-extras-0.3.4-8IjmPNCBZNn5yOreI8HE6Y
key: contravariant-extras-0.3.4-8IjmPNCBZNn5yOreI8HE6Y
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
abi: 174741bd1eb462283799f4c79afe9c21
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
import-dirs: /usr/lib/ghc-8.6.1/site-local/contravariant-extras-0.3.4
library-dirs: /usr/lib/ghc-8.6.1/site-local/contravariant-extras-0.3.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/contravariant-extras-0.3.4
hs-libraries: HScontravariant-extras-0.3.4-8IjmPNCBZNn5yOreI8HE6Y
depends:
    base-4.12.0.0 base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    contravariant-1.5-4tjvhiNPMk29NhGPKE1GIF template-haskell-2.14.0.0
    tuple-th-0.2.5-GwUCeaN8vvJEBlSQcMUthO
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
